@@ -22,6 +22,7 @@
 #define __SCIM_PRIME_PREFS_H__
 
 #define SCIM_PRIME_CONFIG_COMMAND                             "/IMEngine/PRIME/Command"
+#define SCIM_PRIME_CONFIG_LANGUAGE                            "/IMEngine/PRIME/Language"
 #define SCIM_PRIME_CONFIG_TYPING_METHOD                       "/IMEngine/PRIME/TypingMethod"
 #define SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD                   "/IMEngine/PRIME/ConvertOnPeriod"
 #define SCIM_PRIME_CONFIG_COMMIT_PERIOD                       "/IMEngine/PRIME/CommitPeriod"
@@ -80,6 +81,7 @@
 #define SCIM_PRIME_CONFIG_SET_MODE_HALF_KATAKANA_KEY          "/IMEngine/PRIME/SetModeHalfKatakanaKey"
 #define SCIM_PRIME_CONFIG_SET_MODE_RAW_KEY                    "/IMEngine/PRIME/SetModeRawKey"
 #define SCIM_PRIME_CONFIG_SET_MODE_WIDE_ASCII_KEY             "/IMEngine/PRIME/SetModeWideAsciiKey"
+#define SCIM_PRIME_CONFIG_TOGGLE_ON_OFF_KEY                   "/IMEngine/PRIME/ToggleOnOffKey"
 #define SCIM_PRIME_CONFIG_TOGGLE_LANGUAGE_KEY                 "/IMEngine/PRIME/ToggleLanguageKey"
 #define SCIM_PRIME_CONFIG_REGISTER_WORD_KEY                   "/IMEngine/PRIME/RegisterWordKey"
 #define SCIM_PRIME_CONFIG_RECOVERY_KEY                        "/IMEngine/PRIME/RecoveryKey"
@@ -88,6 +90,7 @@
 #define SCIM_PRIME_CONFIG_CANDIDATE_COMMENT_COLOR             "/IMEngine/PRIME/CandidateCommentColor"
 
 #define SCIM_PRIME_CONFIG_COMMAND_DEFAULT                     "prime"
+#define SCIM_PRIME_CONFIG_LANGUAGE_DEFAULT                    "Japanese"
 #define SCIM_PRIME_CONFIG_TYPING_METHOD_DEFAULT               ""
 #define SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD_DEFAULT           false
 #define SCIM_PRIME_CONFIG_COMMIT_PERIOD_DEFAULT               true
@@ -145,6 +148,7 @@
 #define SCIM_PRIME_CONFIG_SET_MODE_HALF_KATAKANA_KEY_DEFAULT  "F8"
 #define SCIM_PRIME_CONFIG_SET_MODE_WIDE_ASCII_KEY_DEFAULT     "F9"
 #define SCIM_PRIME_CONFIG_SET_MODE_RAW_KEY_DEFAULT            "F10"
+#define SCIM_PRIME_CONFIG_TOGGLE_ON_OFF_KEY_DEFAULT           "Zenkaku_Hankaku"
 #define SCIM_PRIME_CONFIG_TOGGLE_LANGUAGE_KEY_DEFAULT         "F11"
 #define SCIM_PRIME_CONFIG_REGISTER_WORD_KEY_DEFAULT           "Control+w, Control+W"
 #define SCIM_PRIME_CONFIG_RECOVERY_KEY_DEFAULT                "Control+Alt+r"
